#

import requests

from mesghub import MesgHubMessage


class MesgHubClient(object):
    def __init__(self, apikey=None, version="1.2"):
        self._apikey = apikey
        self._version = version
        #
        self._sess = requests.Session()

    def dispose(self):
        if self._sess is not None:
            self._sess.close()
            self._sess = None

    def messageCount(self, mailbox):
        params = {
            'apikey': self._apikey,
            'local': mailbox
        }
        headers = {
            "X-Client-Version": self._version,
        }
        res = self._sess.get("http://www.mesghub.com/msg_count", params=params, headers=headers, verify=False, timeout=5)
        if res.status_code != 200:
            raise EnvironmentError("Internal Server Error")
        packet = res.json()
        result = packet.get('count')
        return result

    def messageIndex(self, mailbox):
        result = None
        #
        params = {
            'apikey': self._apikey,
            'local': mailbox
        }
        headers = {
            "X-Client-Version": self._version,
        }
        res = self._sess.get("http://www.mesghub.com/msg_index", params=params, headers=headers, verify=False, timeout=5)
        #
        if res.status_code != 200:
            raise EnvironmentError("Internal Server Error")
        #
        packet = res.json()
        #
        if isinstance(packet, list):
            result = []
            for msg in packet:
                m = MesgHubMessage(**msg)
                result.append(m)
        #
        return result

    def messageFetch(self, msgid):
        result = None
        #
        params = {
            'apikey': self._apikey,
            'msgid': msgid
        }
        headers = {
            "X-Client-Version": self._version,
        }
        res = self._sess.get("http://www.mesghub.com/msg", params=params, headers=headers, verify=False, timeout=5)
        #
        if res.status_code != 200:
            raise EnvironmentError("Internal Server Error")
        #
        result = res.content
        #
        return result


if __name__ == "__main__":
    c = MesgHubClient()
    c.messageCount('auduiopoisk21')
    c.dispose()
